#
# spec file for package python-python-crontab
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-crontab
Version:        2.7.1
Release:        1.3
Summary:        Python Crontab API
License:        LGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://gitlab.com/doctormo/python-crontab/
Source:         https://files.pythonhosted.org/packages/source/p/python-crontab/python-crontab-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil
Recommends:     cronie
Recommends:     python-cron-descriptor
Recommends:     python-croniter
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module cron-descriptor}
BuildRequires:  %{python_module croniter}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module testsuite if %python-base >= 3}
BuildRequires:  cronie
# /SECTION
%python_subpackages

%description
Crontab module for reading and writing crontab files and
accessing the system cron automatically using an API.

%prep
%setup -q -n python-crontab-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%{python_expand mkdir -p build/bin
ln -s %{_bindir}/$python build/bin/python
}
export PATH=$PWD/build/bin:$PATH
# test_07_non_posix_shell - only for Windows
%pytest -k "not test_07_non_posix_shell"

%files %{python_files}
%doc README.rst
%license COPYING AUTHORS
%{python_sitelib}/cronlog.py
%{python_sitelib}/crontab.py
%{python_sitelib}/crontabs.py
%{python_sitelib}/python_crontab-%{version}*-info
%pycache_only %{python_sitelib}/__pycache__

%changelog
* Tue Feb 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.7.1:
  * Fix #104, confirm removal of python2.7 support
- 2.7.0:
  * Add feature to insert new commands in the middle of the cron. Fix #101
  * Do not log invalid comments as errors
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.6.0
- Fix #87 with specials flag on rendering options
  * Fix #82 with a cron_command API and README updates
  * Fix #88 with comment change
  * Merge branch 'issue-cron-weekdays-vs-python-weekdays' into 'master'
  * Fix test_02_days_per_year calculations incorrect
  * Fix #81 make a command valid when setting the command
  * bump version
  * Fix #75 apply disabled comment prefix before pre-comment
  * Fix #73 add support for percent sign stdin and escaping
  * Fix #71 record pre-comment styles faithfully for re-rendering
* Thu May  6 2021 Ben Greiner <code@bnavigator.de>
- Fix testsuite and devel BuildRequirements for different flavors
* Mon Jan 25 2021 John Vandenberg <jayvdb@gmail.com>
- Fix Python 3.6 builds
* Wed Aug  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.5.1
  * Update crontab class to allow with context manager
  * Convert file to unix format
  * add support for percent sign stdin and escaping
* Mon Mar 23 2020 pgajdos@suse.com
- version update to 2.4.0
  * no upstream changelog found
* Wed Sep 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable flaky test test_04_schedule_ten
* Tue Sep 17 2019 Jan Engelhardt <jengelh@inai.de>
- Expand description.
* Tue Sep 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Mon Sep 16 2019 John Vandenberg <jayvdb@gmail.com>
- Update to single spec and activate test suite
- Update to v2.3.8
* Sun Aug 23 2015 Sergey Ivanov <isn77@list.ru>
- Initial spec for v1.7.2
